@@ -1,9 +1,5 @@
 use super::GenericParserError;
-use crate::generic::{
-  claims::{PasetoClaim, PasetoClaimError, ValidatorFn, ValidatorMap},
-  Footer, ImplicitAssertion, ImplicitAssertionCapable, Local, Paseto, PasetoAsymmetricPublicKey, PasetoSymmetricKey,
-  Public, V1, V2, V3, V4,
-};
+use crate::generic::*;
 
 use core::marker::PhantomData;
 use serde_json::Value;
@@ -39,6 +35,7 @@ impl<'a, Version, Purpose> GenericParser<'a, Version, Purpose> {
     self
   }
 
+  #[cfg(feature = "serde")]
   fn set_validation_claim<T: PasetoClaim + 'static + serde::Serialize>(
     &mut self,
     value: T,
@@ -55,6 +52,7 @@ impl<'a, Version, Purpose> GenericParser<'a, Version, Purpose> {
     self
   }
 
+  #[cfg(feature = "serde")]
   pub fn validate_claim<T: PasetoClaim + 'static + serde::Serialize>(
     &mut self,
     value: T,
@@ -63,6 +61,7 @@ impl<'a, Version, Purpose> GenericParser<'a, Version, Purpose> {
     self.set_validation_claim(value, Some(validation_closure))
   }
 
+  #[cfg(feature = "serde")]
   pub fn check_claim<T: PasetoClaim + 'static + serde::Serialize>(&mut self, value: T) -> &mut Self {
     self.set_validation_claim(value, None)
   }
@@ -131,6 +130,7 @@ impl<'a, Version, Purpose> GenericParser<'a, Version, Purpose> {
   }
 }
 
+#[cfg(feature = "v1_local")]
 impl<'a> GenericParser<'a, V1, Local> {
   pub fn parse(
     &self,
@@ -144,6 +144,7 @@ impl<'a> GenericParser<'a, V1, Local> {
   }
 }
 
+#[cfg(feature = "v2_local")]
 impl<'a> GenericParser<'a, V2, Local> {
   pub fn parse(
     &mut self,
@@ -157,6 +158,7 @@ impl<'a> GenericParser<'a, V2, Local> {
   }
 }
 
+#[cfg(feature = "v3_local")]
 impl<'a> GenericParser<'a, V3, Local> {
   pub fn parse(
     &mut self,
@@ -171,6 +173,7 @@ impl<'a> GenericParser<'a, V3, Local> {
   }
 }
 
+#[cfg(feature = "v4_local")]
 impl<'a> GenericParser<'a, V4, Local> {
   pub fn parse(
     &mut self,
@@ -185,6 +188,7 @@ impl<'a> GenericParser<'a, V4, Local> {
   }
 }
 
+#[cfg(feature = "v1_public")]
 impl<'a> GenericParser<'a, V1, Public> {
   pub fn parse(
     &mut self,
@@ -198,6 +202,7 @@ impl<'a> GenericParser<'a, V1, Public> {
   }
 }
 
+#[cfg(feature = "v2_public")]
 impl<'a> GenericParser<'a, V2, Public> {
   pub fn parse(
     &mut self,
@@ -213,6 +218,7 @@ impl<'a> GenericParser<'a, V2, Public> {
 
 //TODO: V3, Public
 
+#[cfg(feature = "v4_public")]
 impl<'a> GenericParser<'a, V4, Public> {
   pub fn parse(
     &mut self,
@@ -233,7 +239,7 @@ impl<'a, Version, Purpose> Default for GenericParser<'a, Version, Purpose> {
   }
 }
 
-#[cfg(test)]
+#[cfg(all(test, feature = "v2"))]
 mod parsers {
 
   use std::convert::TryFrom;
@@ -241,6 +247,8 @@ mod parsers {
   use crate::generic::claims::*;
   use crate::generic::*;
   use anyhow::Result;
+
+  #[cfg(feature = "public")]
   #[test]
   fn full_parser_test_v2_public() -> Result<()> {
     //create a key
@@ -297,6 +305,7 @@ mod parsers {
     Ok(())
   }
 
+  #[cfg(feature = "local")]
   #[test]
   fn full_parser_test() -> Result<()> {
     //create a key
@@ -347,6 +356,7 @@ mod parsers {
     Ok(())
   }
 
+  #[cfg(feature = "local")]
   #[test]
   fn basic_claim_validation_test() -> Result<()> {
     //create a key
@@ -373,6 +383,7 @@ mod parsers {
     Ok(())
   }
 
+  #[cfg(feature = "local")]
   #[test]
   fn claim_custom_validator_test() -> Result<()> {
     //create a key
@@ -407,6 +418,7 @@ mod parsers {
     Ok(())
   }
 
+  #[cfg(feature = "local")]
   #[test]
   fn claim_custom_validator_failure_test() -> Result<()> {
     //create a key
@@ -444,6 +456,7 @@ mod parsers {
     Ok(())
   }
 
+  #[cfg(feature = "local")]
   #[test]
   fn custom_claim_custom_validator_test() -> Result<()> {
     //create a key
@@ -482,6 +495,7 @@ mod parsers {
     Ok(())
   }
 
+  #[cfg(feature = "local")]
   #[test]
   fn missing_claim_validation_test() -> Result<()> {
     //create a key
